# Providing Feedback

While Github Issues are a great way for us to better understand any issues your having with Bloqade as well as provide us with feature requests, we're always looking for ways to collect more general feedback about what the user experience with Bloqade is like.

To do that we have [this form](https://share.hsforms.com/1FJjYan2VQC6NfrQ5IPAcewdrwvd) where you can provide your thoughts after using/experimenting/tinkering/hacking with Bloqade.

Your feedback will help guide the future of Bloqade's design so be honest and know that you're contributing to the future of Quantum Computing with Neutral Atoms!
